
# load the splancs package
library(splancs)

# set some variables for later use
iterations <- 1000
distances <- seq(from=0, to=120, by=1)

# read the point data for live trees
live_data <- read.table("live_all.txt", header=T)

# filter out points for Species 1
Sp1_data <- subset(live_data, live_data$Species == 4)
Sp1_pts <- as.points(Sp1_data$X, Sp1_data$Y)

# find max and min values for X and Y
x_min <- min(Sp1_data$X)
x_max <- max(Sp1_data$X)
y_min <- min(Sp1_data$Y)
y_max <- max(Sp1_data$Y)

# generate a bounding polygon
sbox_pts <- as.points(c(x_min,x_min,x_max,x_max), c(y_min,y_max,y_min,y_max))
Sp1_poly <- sbox(sbox_pts)

# plot the data for Species 1
polymap(Sp1_poly)
pointmap(Sp1_pts,add=T)

# calculate Ripley's K for Species 1 (kHat1) and modified Ripley's K (lhat1)
kHat1 <- khat(Sp1_pts, Sp1_poly, distances)
lHat1 <- distances - sqrt(kHat1/pi)

# generate 95% CI for Ripley's K and modified Ripley's K
kHat_CI <- Kenv.csr(length(Sp1_data[,1]), Sp1_poly, iterations, distances)
lHat_upper_CI <- distances - sqrt(kHat_CI$upper/pi)
lHat_lower_CI <- distances - sqrt(kHat_CI$lower/pi)

# plot the modified Ripley's K with its CI
plot(distances, lHat1, type="l", col="blue", xlab="Radius (m)", ylab="Modified Ripley's K",ylim=c(-15,15))
abline(h=0, lty="dashed")
lines(distances, lHat_upper_CI, lty=2)
lines(distances, lHat_lower_CI, lty=2)
